@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudformation._jsii
 import aws_cdk.aws_iam._jsii
@@ -17,7 +17,7 @@ import cdk_iam_floyd._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-ec2-key-pair", "1.6.0", __name__[0:-6], "cdk-ec2-key-pair@1.6.0.jsii.tgz"
+    "cdk-ec2-key-pair", "1.7.0", __name__[0:-6], "cdk-ec2-key-pair@1.7.0.jsii.tgz"
 )
 
 __all__ = [
